@@ -3,13 +3,20 @@
 #![feature(map_first_last)]
 #![feature(arbitrary_enum_discriminant)]
 
-mod command;
+pub mod command;
 mod errors;
 pub mod nodes;
+#[cfg(feature = "storage")]
+mod store;
 pub mod traits;
 
-pub use errors::{NoteError, Result, NoteErrorKind};
-pub use nodes::{ASTKind, ASTNode, ASTNodes};
+pub use self::{
+    errors::{NoteError, NoteErrorKind, Result},
+    nodes::{ASTKind, ASTNode, ASTNodes},
+};
+
+#[cfg(feature = "storage")]
+pub use self::store::*;
 
 pub mod utils {
     pub use text_utils::*;
