@@ -1,11 +1,15 @@
 use super::*;
-use std::{cmp::Ordering, ops::Range};
+use std::{
+    cmp::Ordering,
+    ops::{Deref, Range},
+};
 
+/// Used to represent a node with positions
 #[derive(Clone, Eq)]
 pub struct Literal<T> {
-    ///
+    /// The actual value
     pub value: T,
-    //
+    // The Start offset and end offset
     pub range: Option<Range<usize>>,
 }
 
@@ -49,3 +53,11 @@ impl<T: Ord> Ord for Literal<T> {
         self.value.cmp(&other.value)
     }
 }
+
+impl<T> Deref for Literal<T> {
+    type Target = T;
+
+    fn deref(&self) -> &Self::Target {
+        &self.value
+    }
+}
